Added CERES_ prefix to the DISALLOW macros.

Change-Id: Ib81e9112e8bbc6ed6cb52f21825df0f6e659be51
diff --git a/include/ceres/cost_function.h b/include/ceres/cost_function.h
index 84403d9..9b010f7 100644
--- a/include/ceres/cost_function.h
+++ b/include/ceres/cost_function.h
@@ -119,7 +119,7 @@
   // number of outputs (residuals).
   vector<int16> parameter_block_sizes_;
   int num_residuals_;
-  DISALLOW_COPY_AND_ASSIGN(CostFunction);
+  CERES_DISALLOW_COPY_AND_ASSIGN(CostFunction);
 };
 
 }  // namespace ceres
diff --git a/include/ceres/loss_function.h b/include/ceres/loss_function.h
index 81add02..c95a0a0 100644
--- a/include/ceres/loss_function.h
+++ b/include/ceres/loss_function.h
@@ -249,7 +249,7 @@
   internal::scoped_ptr<const LossFunction> rho_;
   const double a_;
   const Ownership ownership_;
-  DISALLOW_COPY_AND_ASSIGN(ScaledLoss);
+  CERES_DISALLOW_COPY_AND_ASSIGN(ScaledLoss);
 };
 
 // Sometimes after the optimization problem has been constructed, we
@@ -314,7 +314,7 @@
  private:
   internal::scoped_ptr<const LossFunction> rho_;
   Ownership ownership_;
-  DISALLOW_COPY_AND_ASSIGN(LossFunctionWrapper);
+  CERES_DISALLOW_COPY_AND_ASSIGN(LossFunctionWrapper);
 };
 
 }  // namespace ceres
diff --git a/include/ceres/problem.h b/include/ceres/problem.h
index 0ca6100..9710e46 100644
--- a/include/ceres/problem.h
+++ b/include/ceres/problem.h
@@ -257,7 +257,7 @@
  private:
   friend class internal::SolverImpl;
   internal::scoped_ptr<internal::ProblemImpl> problem_impl_;
-  DISALLOW_COPY_AND_ASSIGN(Problem);
+  CERES_DISALLOW_COPY_AND_ASSIGN(Problem);
 };
 
 }  // namespace ceres
diff --git a/include/ceres/internal/macros.h b/include/ceres/internal/macros.h
index 05d6287..7dd4e3e 100644
--- a/include/ceres/internal/macros.h
+++ b/include/ceres/internal/macros.h
@@ -43,11 +43,13 @@
 //
 // For disallowing only assign or copy, write the code directly, but declare
 // the intend in a comment, for example:
-// void operator=(const TypeName&);  // DISALLOW_ASSIGN
-// Note, that most uses of DISALLOW_ASSIGN and DISALLOW_COPY are broken
-// semantically, one should either use disallow both or neither. Try to
-// avoid these in new code.
-#define DISALLOW_COPY_AND_ASSIGN(TypeName) \
+//
+//   void operator=(const TypeName&);  // _DISALLOW_ASSIGN
+
+// Note, that most uses of CERES_DISALLOW_ASSIGN and CERES_DISALLOW_COPY
+// are broken semantically, one should either use disallow both or
+// neither. Try to avoid these in new code.
+#define CERES_DISALLOW_COPY_AND_ASSIGN(TypeName) \
   TypeName(const TypeName&);               \
   void operator=(const TypeName&)
 
@@ -57,9 +59,9 @@
 // This should be used in the private: declarations for a class
 // that wants to prevent anyone from instantiating it. This is
 // especially useful for classes containing only static methods.
-#define DISALLOW_IMPLICIT_CONSTRUCTORS(TypeName) \
+#define CERES_DISALLOW_IMPLICIT_CONSTRUCTORS(TypeName) \
   TypeName();                                    \
-  DISALLOW_COPY_AND_ASSIGN(TypeName)
+  CERES_DISALLOW_COPY_AND_ASSIGN(TypeName)
 
 // The arraysize(arr) macro returns the # of elements in an array arr.
 // The expression is a compile-time constant, and therefore can be